import click

__all__ = ['cli']


@click.group()
def cli():
    """
    Basic entry point for manhattan project scripts `manhattan {command} ...`
    """
    pass


# Import commands

from . import blueprints
from . import projects



import click
from cookiecutter.main import cookiecutter

from . import cli


@click.command()
def create_blueprint():
    """Create a new manhattan project"""
    cookiecutter(
        'git@git.getme.co.uk:manhattan/manhattan_blueprints_base.git'
    )

cli.add_command(create_blueprint)



import click
from cookiecutter.main import cookiecutter
from manhattan.secure import random_code

from . import cli


@click.command()
def create_project():
    """Create a new manhattan project"""
    cookiecutter(
        'git@git.getme.co.uk:manhattan/manhattan_projects_cms.git',
        extra_context={
            'csrf_secret_key': random_code(32),
            'secret_key': random_code(32)
        }
    )

cli.add_command(create_project)
